@@ -202,6 +202,7 @@ class AsyncioTelnetServer:
         except ConnectionError:
             async with self._lock:
                 network_writer.close()
+                await network_writer.wait_closed()
                 if self._reader_process == network_reader:
                     self._reader_process = None
                     # Cancel current read from this reader
@@ -216,6 +217,8 @@ class AsyncioTelnetServer:
             try:
                 writer.write_eof()
                 await writer.drain()
+                writer.close()
+                await writer.wait_closed()
             except (AttributeError, ConnectionError):
                 continue
 
